from setuptools import setup, find_packages

VERSION = '0.0.5'
DESCRIPTION = 'Python database'

setup(
    name='lotusdb',
    version=VERSION,
    author='d3tu',
    author_email='jpafly@gmail.com',
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=['database'],
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3',
        'Operating System :: Unix',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
    ]
)


import os, json
class Database:
  def __init__(self, path = 'data.db'):
    self.path = path
    if not os.path.exists(path): 
      with open(path, 'x') as f: f.close()
  def put(self, data):
    with open(self.path, 'a') as f: f.write(json.dumps(data, separators=(',', ':')) + '\n'); f.close()
  def find(self, cb):
    with open(self.path, 'r') as f:
      r = ''
      for l in f:
        j = json.loads(l)
        try:
          if cb(j): r = j; break
        except: None
      f.close(); return r
  def remove(self, cb):
    with open(self.path, 'r') as r, open(self.path + '.bak', 'w') as w:
      o = True
      for l in r:
        try:
          if cb(json.loads(l)): o = False
          else: o = True
        except: None
        if o: w.write(l)
      r.close(); w.close(); os.remove(self.path); os.rename(self.path + '.bak', self.path)